@@ -5,17 +5,18 @@
 // Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
 //
 
+#include "spriteanim.h"
 #include "spritemisc.h"
 #include "spritepm.h"
-#include "spriteanim.h"
-#include <kdebug.h>
 
+#include <kdebug.h>
+#include <kconfiggroup.h>
 //===========================================================================
 //
 // SpriteObject stores the animations that create an object
 //
-SpriteObject::SpriteObject(SpritePixmapSequence *seq, QCanvas *c )
-    : QCanvasSprite(seq, c),
+SpriteObject::SpriteObject(SpritePixmapSequence *seq, Q3Canvas *c )
+    : Q3CanvasSprite(seq, c),
       mCycle(0),
       mLifeSpan(-1),
       mSeq(seq)
@@ -52,13 +53,13 @@ bool SpriteObject::outOfBounds() const
 //
 // SpriteDef stores the animations that create an object
 //
-SpriteDef::SpriteDef(KConfigBase &config)
+SpriteDef::SpriteDef(KConfigGroup &config)
 {
     read(config);
 }
 
 //---------------------------------------------------------------------------
-SpriteObject *SpriteDef::create( QCanvas *c )
+SpriteObject *SpriteDef::create( Q3Canvas *c )
 {
     SpriteObject *sprite = 0;
     if (mSeq)
@@ -82,7 +83,7 @@ SpriteObject *SpriteDef::create( QCanvas *c )
 }
 
 //---------------------------------------------------------------------------
-void SpriteDef::read(KConfigBase &config)
+void SpriteDef::read(KConfigGroup &config)
 {
     mDirX.set(config.readEntry("DirectionX", "0"));
     mDirY.set(config.readEntry("DirectionY", "0"));
@@ -90,18 +91,19 @@ void SpriteDef::read(KConfigBase &config)
     mStartY.set(config.readEntry("StartY", "0"));
     mEndX.set(config.readEntry("EndX", "10000"));
     mEndY.set(config.readEntry("EndY", "10000"));
-    mLifeSpan = config.readNumEntry("LifeSpan", -1);
-    mZ = config.readNumEntry("Z", 1);
+    mLifeSpan = config.readEntry("LifeSpan", -1);
+    mZ = config.readEntry("Z", 1);
     QString animation = config.readEntry("Animation", "");
-    mSeq = SpriteSequenceManager::manager()->load(config, animation);
-    kdDebug() << "Set Z = " << mZ << endl;
+    KConfigBase *grp = config.config();
+    mSeq = SpriteSequenceManager::manager()->load(*grp, animation);
+    kDebug() << "Set Z = " << mZ;
 }
 
 //===========================================================================
 //
 // SpriteGroup
 //
-SpriteGroup::SpriteGroup(QCanvas *c, KConfigBase &config)
+SpriteGroup::SpriteGroup(Q3Canvas *c, KConfigGroup &config)
     : mCanvas(c)
 {
     mAvailable.setAutoDelete(true);
@@ -112,7 +114,7 @@ SpriteGroup::SpriteGroup(QCanvas *c, KConfigBase &config)
 //---------------------------------------------------------------------------
 void SpriteGroup::next()
 {
-    QPtrListIterator<SpriteObject> it(mActive);
+    Q3PtrListIterator<SpriteObject> it(mActive);
 
     for (; it.current(); ++it)
     {
@@ -141,20 +143,22 @@ void SpriteGroup::refresh()
 
 
 //---------------------------------------------------------------------------
-void SpriteGroup::read(KConfigBase &config)
+void SpriteGroup::read(KConfigGroup &config)
 {
+    qDebug()<<" void SpriteGroup::read(KConfigBase &config) :"<<config.name();
     SpriteRange countRange(config.readEntry("Count", "1"));
     mCount = countRange.random();
 
     mRefresh.set(config.readEntry("Refresh", "1000"));
 
-    QStrList anims;
-    config.readListEntry("Animations", anims);
-
-    for (anims.first(); anims.current(); anims.next())
+    QStringList anims;
+    anims = config.readEntry("Animations",anims);
+    QStringList::const_iterator lst;
+    	
+	for (lst = anims.constBegin(); lst != anims.constEnd(); ++lst)
     {
-        config.setGroup(anims.current());
-        SpriteDef *obj = new SpriteDef(config);
+	KConfigGroup grp(config.config(), *lst);
+        SpriteDef *obj = new SpriteDef(grp);
         mAvailable.append(obj);
     }
 }
